PDS DOI Service
===============

The Planetary Data System (PDS_) Digital Object Identifier (DOI_) Service
enables management of DOIs for PDS with the following operations: list, reserve,
draft, review, and release.

The PDS DOIs are registered through the `DataCite`_ infrastructure.

Currently, this service is deployed as a Python package
``pds-doi-service`` and is executed locally through a command line
``pds-doi-cmd`` or remotely through the web API server ``pds-doi-api``.


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation/index
   usage/index
   development/index
   support/index


.. _dataCite: https://datacite.org
.. _DOI: https://doi.org/
.. _PDS: https://pds.nasa.gov/
